Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Action ¶
type Action struct {
Name string
Steps []Step // using UnmarshalYAML so that we don't need a custom type per action
}
func (Action) GetSteps ¶
func (a Action) GetSteps() []builder.ExecutableStep
func (Action) MakeSteps ¶
func (a Action) MakeSteps() interface{}
MakeSteps builds a slice of Step for data to be unmarshaled into.
func (Action) MarshalYAML ¶
MarshalYAML converts the action back to a YAML representation install:
handlebars: ...
func (Action) SetDefaults ¶
func (a Action) SetDefaults()
func (*Action) UnmarshalYAML ¶
UnmarshalYAML takes any yaml in this form ACTION: - handlebars: ... and puts the steps into the Action.Steps field
type Actions ¶
type Actions []Action
Actions is a set of actions, and the steps, passed from Porter.
func (*Actions) UnmarshalYAML ¶
UnmarshalYAML takes chunks of a porter.yaml file associated with this mixin and populates it on the current action set. install:
handlebars: ... handlebars: ...
upgrade:
handlebars: ...
type BuildInput ¶
type BuildInput struct {
Config MixinConfig
}
BuildInput represents stdin passed to the mixin for the build command.
type Instruction ¶
type Instruction struct {
Template string `yaml:"template"`
Data string `yaml:"data"`
Destination string `yaml:"destination,omitempty"`
Description string `yaml:"description"`
Helpers []string `yaml:"helpers"`
SuppressOutput bool `yaml:"suppress-output,omitempty"`
}
func (Instruction) GetArguments ¶
func (s Instruction) GetArguments() []string
func (Instruction) GetCommand ¶
func (s Instruction) GetCommand() string
hbs -s --helper /myhelpers.js --data /data.json -- /template.yaml
func (Instruction) GetFlags ¶
func (s Instruction) GetFlags() builder.Flags
func (Instruction) GetSuffixArguments ¶
func (s Instruction) GetSuffixArguments() []string
func (*Instruction) SetDefaults ¶
func (s *Instruction) SetDefaults()
func (Instruction) SuppressesOutput ¶
func (s Instruction) SuppressesOutput() bool
type Mixin ¶
func (*Mixin) Build ¶
Build will generate the necessary Dockerfile lines for an invocation image using this mixin
func (*Mixin) PrintSchema ¶
type MixinConfig ¶
type MixinConfig struct {
ClientVersion string `yaml:"clientVersion,omitempty"`
}
type Step ¶
type Step struct {
*Instruction `yaml:"handlebars"`
}
type TestMixin ¶
type TestMixin struct {
*Mixin
TestContext *context.TestContext
}
func NewTestMixin ¶
NewTestMixin initializes a mixin test client, with the output buffered, and an in-memory file system.